@@ -3,6 +3,8 @@ from __future__ import annotations
 import os
 import shutil
 
+import pytest
+
 from monty.tempfile import ScratchDir
 
 TEST_DIR = os.path.join(os.path.dirname(os.path.abspath(__file__)), "test_files")
@@ -49,23 +51,24 @@ class TestScratchDir:
         # We write a pre-scratch file.
         with open("pre_scratch_text", "w") as f:
             f.write("write")
-        init_gz = [f for f in os.listdir(os.getcwd()) if f.endswith(".gz")]
-        with (
-            ScratchDir(
-                self.scratch_root,
-                copy_from_current_on_enter=True,
-                copy_to_current_on_exit=True,
-                gzip_on_exit=True,
-            ),
-            open("scratch_text", "w") as f,
-        ):
-            f.write("write")
+        init_gz_files = [f for f in os.listdir(os.getcwd()) if f.endswith(".gz")]
+        with pytest.warns(match="Both 3000_lines.txt and 3000_lines.txt.gz exist."):
+            with (
+                ScratchDir(
+                    self.scratch_root,
+                    copy_from_current_on_enter=True,
+                    copy_to_current_on_exit=True,
+                    gzip_on_exit=True,
+                ),
+                open("scratch_text", "w") as f,
+            ):
+                f.write("write")
         files = os.listdir(os.getcwd())
 
-        # Make sure the stratch_text.gz exists
+        # Make sure the scratch_text.gz exists
         assert "scratch_text.gz" in files
         for f in files:
-            if f.endswith(".gz") and f not in init_gz:
+            if f.endswith(".gz") and f not in init_gz_files:
                 os.remove(f)
         os.remove("pre_scratch_text")
 
